DataWedgeAppAssociation class

Defines an app association for a DataWedge profile.

This specifies which app (and optionally which activities) the profile applies to.

Constructors

DataWedgeAppAssociation({required String packageName, List<String> activityList = const <String>[DataWedgeApi.wildcard]})
Creates a new app association.
const

Properties

activityList List<String>
List of activities the profile applies to.
final
hashCode int
The hash code for this object.
no setterinherited
packageName String
The Android package name of the associated app.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this association to a Map for DataWedge.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited