DataWedgeBeepSettings class

Beep notification settings for Bluetooth scanners.

Constructors

DataWedgeBeepSettings({required int frequency, required int onTime, required int offTime, required int repeatCount})
Creates new beep settings.
const

Properties

frequency int
The beep frequency in Hz.
final
hashCode int
The hash code for this object.
no setterinherited
offTime int
The off time in milliseconds.
final
onTime int
The on time in milliseconds.
final
repeatCount int
The number of times to repeat the beep.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts these settings to a Map for DataWedge.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited