DataWedgeConfigMode class

Configuration modes for creating or updating DataWedge profiles.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

createIfNotExist → const String
Create the profile only if it doesn't already exist.
overwrite → const String
Overwrite the existing profile configuration completely.
update → const String
Update the existing profile with new settings (merge).