DataWedgeCustomNotificationRequest class

Request for custom notifications to a Bluetooth scanner.

Constructors

DataWedgeCustomNotificationRequest({required String deviceIdentifier, DataWedgeLedSettings? ledSettings, List<DataWedgeBeepSettings> beepSettings = const <DataWedgeBeepSettings>[], List<DataWedgeVibrationSettings> vibrationSettings = const <DataWedgeVibrationSettings>[]})
Creates a new custom notification request.
const

Properties

beepSettings List<DataWedgeBeepSettings>
Beep notification settings.
final
deviceIdentifier String
The identifier of the Bluetooth scanner.
final
hashCode int
The hash code for this object.
no setterinherited
ledSettings DataWedgeLedSettings?
LED notification settings (optional).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vibrationSettings List<DataWedgeVibrationSettings>
Vibration notification settings.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this request to a Map for DataWedge.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited