DataWedgeDisabledAppListMode class

Modes for updating the disabled app list.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

overwrite → const String
Replace the entire disabled list with the new one.
remove → const String
Remove apps from the disabled list.
update → const String
Add apps to the existing disabled list.