overwrite constant
String
const overwrite
Replace the entire disabled list with the new one.
Implementation
static const String overwrite = 'OVERWRITE';
Replace the entire disabled list with the new one.
static const String overwrite = 'OVERWRITE';