DataWedgeEventType class

Event types emitted by the DataWedge service.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

commandResult → const String
Result of a command sent to DataWedge.
debug → const String
Debug event from DataWedge.
notification → const String
A notification event (scanner status, profile switch, etc.).
scan → const String
A barcode or RFID scan event.
unknown → const String
Unknown or unrecognized event type.