DataWedgeImportConfigRequest class

Request for importing DataWedge configuration.

Constructors

DataWedgeImportConfigRequest({required String folderPath, List<String>? fileList})
Creates a new import config request.
const

Properties

fileList List<String>?
Optional list of specific files to import.
final
folderPath String
The folder path for importing config files.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this request to a Map for DataWedge.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited