DataWedgeLedSettings class

LED notification settings for Bluetooth scanners.

Constructors

DataWedgeLedSettings({required int color, required int onTime, required int offTime, required int repeatCount})
Creates new LED settings.
const

Properties

color int
The LED color value.
final
hashCode int
The hash code for this object.
no setterinherited
offTime int
The off time in milliseconds.
final
onTime int
The on time in milliseconds.
final
repeatCount int
The number of times to repeat the pattern.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts these settings to a Map for DataWedge.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited