DataWedgeNotificationRequest class
Request for notifying a Bluetooth scanner (LED/beep/vibrate).
Constructors
-
DataWedgeNotificationRequest({required String deviceIdentifier, required List<
int> notificationSettings}) -
Creates a new notification request.
const
Properties
- deviceIdentifier → String
-
The identifier of the Bluetooth scanner.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notificationSettings
→ List<
int> -
The notification settings for the scanner.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this request to a Map for DataWedge.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited