DataWedgeNotificationType class

Notification types for DataWedge events.

Register for these notifications using ZebraDataWedge.registerForNotification.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

configurationUpdate → const String
Notifications when the DataWedge configuration is updated.
profileSwitch → const String
Notifications when the active profile is switched.
scannerStatus → const String
Notifications for scanner state changes (enabled, disabled, waiting, etc.).
workflowStatus → const String
Notifications for workflow state changes.