DataWedgePluginConfiguration class
Configuration for a DataWedge plugin.
Use this to configure plugins like barcode, intent, keystroke, etc.
Constructors
Properties
-
extra
→ Map<
String, dynamic> -
Additional parameters to include.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputPluginName → String?
-
The associated output plugin name (for process plugins).
final
- paramList → Object?
-
Plugin-specific parameters.
final
- pluginName → String
-
The name of the plugin to configure.
final
- resetConfig → bool
-
Whether to reset the plugin configuration before applying.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this configuration to a Map for DataWedge.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited