DataWedgePluginConfiguration constructor
const
DataWedgePluginConfiguration({})
Creates a new plugin configuration.
pluginName is the name of the plugin (use DataWedgePluginName constants).
resetConfig when true, resets the plugin config before applying new settings.
paramList is the plugin-specific parameters.
outputPluginName is the associated output plugin (for process plugins).
extra is additional parameters to include in the configuration.
Implementation
const DataWedgePluginConfiguration({
required this.pluginName,
this.resetConfig = true,
this.paramList,
this.outputPluginName,
this.extra = const <String, dynamic>{},
});