DataWedgeScannerInputAction class
Actions for controlling the scanner input plugin.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- disablePlugin → const String
- Disables the scanner plugin.
- enablePlugin → const String
- Enables the scanner plugin.
- resumePlugin → const String
- Resumes a suspended scanner plugin.
- suspendPlugin → const String
- Suspends the scanner plugin (temporary disable).