DataWedgeSoftScanAction class

Actions for software scan trigger control.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

start → const String
Starts scanning.
stop → const String
Stops scanning.
toggle → const String
Toggles between start and stop.