DataWedgeSoftTriggerAction class

Actions for generic soft trigger control (RFID, Voice, etc.).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

start → const String
Starts the trigger action.
stop → const String
Stops the trigger action.
toggle → const String
Toggles the trigger action.