DataWedgeWorkflowModule class

A module configuration for workflow plugins.

Constructors

DataWedgeWorkflowModule({required String module, required Map<String, dynamic> moduleParams})
Creates a new workflow module configuration.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
module String
The module name.
final
moduleParams Map<String, dynamic>
Parameters for the module.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this module to a Map for DataWedge.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited