DataWedgeWorkflowName class
Predefined workflow names for Zebra DataWedge.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- basicMultibarcode → const String
- Basic multi-barcode scanning workflow.
- containerScanning → const String
- Container scanning workflow.
- documentCapture → const String
- Document capture workflow.
- freeFormCapture → const String
- Free-form text capture workflow.
- freeFormOcr → const String
- Free-form OCR workflow.
- idScanning → const String
- ID document scanning workflow.
- licensePlate → const String
- License plate recognition workflow.
- meterReading → const String
- Meter reading workflow.
- picklistOcr → const String
- Picklist OCR workflow.
- tinNumber → const String
- TIN (Tax Identification Number) scanning workflow.
- vinNumber → const String
- VIN (Vehicle Identification Number) scanning workflow.