createProfile method

Future<void> createProfile(
  1. String profileName, {
  2. String? commandTag,
  3. bool requestResult = true,
})

Creates a new DataWedge profile with the given profileName.

Optionally, a commandTag can be provided to identify the result in the command result event. Set requestResult to false to avoid receiving a result event.

Implementation

Future<void> createProfile(
  String profileName, {
  String? commandTag,
  bool requestResult = true,
}) {
  return sendCommand(
    command: DataWedgeApi.createProfile,
    value: profileName,
    commandTag: commandTag ?? 'CREATE_PROFILE_$profileName',
    requestResult: requestResult,
  );
}