disableScanner method
Disables the barcode scanner.
After calling this, the scanner will not respond to scan triggers until enableScanner is called.
Implementation
Future<void> disableScanner() {
return _platform.disableScanner();
}
Disables the barcode scanner.
After calling this, the scanner will not respond to scan triggers until enableScanner is called.
Future<void> disableScanner() {
return _platform.disableScanner();
}