enumerateWorkflows method

Future<void> enumerateWorkflows({
  1. String? commandTag,
  2. bool requestResult = true,
})

Enumerates all available workflows on the device.

The result is delivered as a command result event on the events stream, listing all configured workflow profiles.

Implementation

Future<void> enumerateWorkflows({
  String? commandTag,
  bool requestResult = true,
}) {
  return _sendQueryCommand(
    command: DataWedgeApi.enumerateWorkflows,
    commandTag: commandTag ?? 'ENUMERATE_WORKFLOWS',
    requestResult: requestResult,
  );
}