getScannerStatus method

Future<void> getScannerStatus({
  1. String? commandTag,
  2. bool requestResult = true,
})

Retrieves the current scanner status.

The result is delivered as a command result event on the events stream, indicating whether the scanner is idle, scanning, waiting, etc.

Implementation

Future<void> getScannerStatus({
  String? commandTag,
  bool requestResult = true,
}) {
  return _sendQueryCommand(
    command: DataWedgeApi.getScannerStatus,
    commandTag: commandTag ?? 'GET_SCANNER_STATUS',
    requestResult: requestResult,
  );
}