sendCommandBundle method

Future<void> sendCommandBundle({
  1. required String command,
  2. required Map<String, dynamic> value,
  3. String? commandTag,
  4. bool requestResult = true,
})

Sends a command with a Map value to DataWedge.

Use this for commands that require complex configuration objects (e.g., DataWedgeApi.setConfig, DataWedgeApi.getConfig).

command is the DataWedge API command string. value is the configuration Map to send. commandTag optionally identifies this command in result events. requestResult when true, a result event will be emitted on the events stream.

Implementation

Future<void> sendCommandBundle({
  required String command,
  required Map<String, dynamic> value,
  String? commandTag,
  bool requestResult = true,
}) {
  return _platform.sendCommandBundle(
    command: command,
    value: value,
    commandTag: commandTag,
    requestResult: requestResult,
  );
}