sendIntent method

Future<void> sendIntent({
  1. required Map<String, dynamic> extras,
  2. String? action,
  3. String? targetPackage,
  4. String? commandTag,
  5. bool requestResult = true,
  6. bool orderedBroadcast = false,
  7. bool includeApplicationPackage = false,
})

Sends a custom intent to DataWedge or another package.

extras contains the intent extras (key-value pairs). action optionally specifies the intent action. targetPackage optionally specifies the target package (defaults to DataWedge). commandTag optionally identifies this command in result events. orderedBroadcast when true, uses ordered broadcast instead of normal broadcast. includeApplicationPackage when true, includes the app package name in the intent.

Implementation

Future<void> sendIntent({
  required Map<String, dynamic> extras,
  String? action,
  String? targetPackage,
  String? commandTag,
  bool requestResult = true,
  bool orderedBroadcast = false,
  bool includeApplicationPackage = false,
}) {
  return _platform.sendIntent(
    extras: extras,
    action: action,
    targetPackage: targetPackage,
    commandTag: commandTag,
    requestResult: requestResult,
    orderedBroadcast: orderedBroadcast,
    includeApplicationPackage: includeApplicationPackage,
  );
}