setDefaultProfile method

Future<void> setDefaultProfile(
  1. String profileName, {
  2. String? commandTag,
  3. bool requestResult = true,
})

Sets the specified profile as the default DataWedge profile.

profileName is the name of the profile to set as default. The default profile is used when no other profile matches the current app.

Implementation

Future<void> setDefaultProfile(
  String profileName, {
  String? commandTag,
  bool requestResult = true,
}) {
  return sendCommand(
    command: DataWedgeApi.setDefaultProfile,
    value: profileName,
    commandTag: commandTag ?? 'SET_DEFAULT_PROFILE_$profileName',
    requestResult: requestResult,
  );
}