eventChannel property
The event channel for receiving scan events from the platform.
Implementation
@visibleForTesting
final EventChannel eventChannel =
const EventChannel('zebra_datawedge/scans');
The event channel for receiving scan events from the platform.
@visibleForTesting
final EventChannel eventChannel =
const EventChannel('zebra_datawedge/scans');