DataWedgeDisabledAppListRequest class
Request for setting the disabled app list.
Constructors
-
DataWedgeDisabledAppListRequest({required String configMode, List<
DataWedgeAppAssociation> appList = const <DataWedgeAppAssociation>[]}) -
Creates a new disabled app list request.
const
Properties
-
appList
→ List<
DataWedgeAppAssociation> -
The list of apps to disable.
final
- configMode → String
-
The mode for updating the disabled app list.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this request to a Map for DataWedge.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited