DataWedgeIntentDelivery class
Intent delivery methods for the intent output plugin.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- broadcast → const int
- Deliver intent via broadcast (most common).
- startActivity → const int
- Deliver intent via startActivity.
- startForegroundService → const int
- Deliver intent via startForegroundService.
- startService → const int
- Deliver intent via startService.