DataWedgePluginName class
Plugin names for DataWedge configuration.
Use these constants when configuring plugins in a profile.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- adf → const String
- Advanced Data Formatting plugin.
- barcode → const String
- Barcode scanning plugin.
- bdf → const String
- Basic Data Formatting plugin.
- dcp → const String
- DataCapture Plus plugin.
- ekb → const String
- Enterprise Keyboard plugin.
- intent → const String
- Intent output plugin.
- ip → const String
- IP output plugin.
- keystroke → const String
- Keystroke output plugin.
- msr → const String
- Magnetic stripe reader plugin.
- rfid → const String
- RFID plugin.
- serial → const String
- Serial input plugin.
- token → const String
- Token plugin.
- voice → const String
- Voice input plugin.
- workflow → const String
- Workflow plugin for advanced data capture.