DataWedgeProcessPluginRequest class
Request to process a plugin in a getConfig command.
Constructors
- DataWedgeProcessPluginRequest({required String pluginName, String? outputPluginName})
-
Creates a new process plugin request.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputPluginName → String?
-
The associated output plugin name.
final
- pluginName → String
-
The name of the plugin to process.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this request to a Map for DataWedge.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited