DataWedgeProfileConfiguration class
Complete configuration for a DataWedge profile.
This class encapsulates all settings for a DataWedge profile including plugin configurations, app associations, and optional features.
Constructors
-
DataWedgeProfileConfiguration({required String profileName, String configMode = DataWedgeConfigMode.createIfNotExist, bool? profileEnabled, bool? resetConfig, List<
DataWedgePluginConfiguration> pluginConfigurations = const <DataWedgePluginConfiguration>[], List<DataWedgeAppAssociation> appAssociations = const <DataWedgeAppAssociation>[], Map<String, dynamic> ? dataCapturePlus, Map<String, dynamic> ? enterpriseKeyboard}) -
Creates a new profile configuration.
const
Properties
-
appAssociations
→ List<
DataWedgeAppAssociation> -
App associations for this profile.
final
- configMode → String
-
How the profile configuration should be applied.
final
-
dataCapturePlus
→ Map<
String, dynamic> ? -
DataCapture Plus configuration (optional).
final
-
enterpriseKeyboard
→ Map<
String, dynamic> ? -
Enterprise Keyboard configuration (optional).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pluginConfigurations
→ List<
DataWedgePluginConfiguration> -
Plugin configurations for this profile.
final
- profileEnabled → bool?
-
Whether the profile is enabled.
final
- profileName → String
-
The name of the profile.
final
- resetConfig → bool?
-
Whether to reset the configuration before applying.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this configuration to a Map for DataWedge.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited