DataWedgeScaleRequest class
Request for scale (weight) operations.
Constructors
- DataWedgeScaleRequest({required String deviceIdentifier, required String command})
-
Creates a new scale request.
const
Properties
- command → String
-
The command to send to the scale.
final
- deviceIdentifier → String
-
The identifier of the scale device.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this request to a Map for DataWedge.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited