DataWedgeScannerIdentifier class
Scanner identifier constants for selecting specific scanners.
Use these constants with ZebraDataWedge.switchScannerByIdentifier and other scanner selection commands.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- auto → const String
- Automatic scanner selection (let DataWedge choose).
- bluetoothDs2278 → const String
- Bluetooth DS2278 scanner.
- bluetoothDs3678 → const String
- Bluetooth DS3678 scanner.
- bluetoothDs8178 → const String
- Bluetooth DS8178 scanner.
- bluetoothGeneric → const String
- Generic Bluetooth scanner.
- bluetoothLi3678 → const String
- Bluetooth LI3678 scanner.
- bluetoothRs5100 → const String
- Bluetooth RS5100 scanner.
- bluetoothRs6000 → const String
- Bluetooth RS6000 scanner.
- bluetoothSsi → const String
- Bluetooth SSI connection.
- bluetoothZebra → const String
- Generic Zebra Bluetooth scanner.
- internalCamera → const String
- Internal camera scanner.
- internalImager → const String
- Internal imager scanner.
- internalLaser → const String
- Internal laser scanner.
- plugableSsi → const String
- Plugable SSI connection.
- plugableSsiRs5000 → const String
- Plugable SSI RS5000 scanner.
- serialSsi → const String
- Serial SSI connection.
- usbSsiDs3608 → const String
- USB SSI DS3608 scanner.
- usbTgcsMp7000 → const String
- USB TGCS MP7000 scale.
- usbZebra → const String
- Generic USB Zebra scanner.