DataWedgeWorkflowConfiguration class
Configuration for a DataWedge workflow.
Constructors
-
DataWedgeWorkflowConfiguration({required String workflowName, String workflowInputSource = DataWedgeWorkflowInputSource.imager, List<
DataWedgeWorkflowModule> modules = const <DataWedgeWorkflowModule>[]}) -
Creates a new workflow configuration.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modules
→ List<
DataWedgeWorkflowModule> -
Modules configured for this workflow.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workflowInputSource → String
-
The input source for the workflow.
final
- workflowName → String
-
The name of the workflow.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this configuration to a Map for DataWedge.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited