cloneProfile method
Clones an existing profile to a new profile.
sourceProfileName is the name of the existing profile to clone.
destinationProfileName is the name for the new cloned profile.
Optionally, a commandTag can be provided to identify the result.
Implementation
Future<void> cloneProfile({
required String sourceProfileName,
required String destinationProfileName,
String? commandTag,
bool requestResult = true,
}) {
return sendCommand(
command: DataWedgeApi.cloneProfile,
value: <String>[sourceProfileName, destinationProfileName],
commandTag: commandTag ?? 'CLONE_PROFILE_$destinationProfileName',
requestResult: requestResult,
);
}