MethodChannelZebraDataWedgePlatform class
Method channel implementation of ZebraDataWedgePlatform.
This class communicates with the native Android platform using MethodChannel for commands and EventChannel for scan events.
- Inheritance
-
- Object
- PlatformInterface
- ZebraDataWedgePlatform
- MethodChannelZebraDataWedgePlatform
Constructors
Properties
- eventChannel → EventChannel
-
The event channel for receiving scan events from the platform.
final
-
events
→ Stream<
Map< String, dynamic> > -
A stream of raw events from the DataWedge service.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel for invoking platform methods.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
configureProfile(
String profileName) → Future< void> -
Creates or updates a DataWedge profile.
override
-
disableScanner(
) → Future< void> -
Disables the scanner.
override
-
enableScanner(
) → Future< void> -
Enables the scanner.
override
-
enumerateScanners(
) → Future< void> -
Enumerates all available scanners.
override
-
getActiveProfile(
) → Future< void> -
Retrieves the active profile name.
override
-
getProfilesList(
) → Future< void> -
Retrieves the list of all profiles.
override
-
getVersionInfo(
) → Future< void> -
Retrieves the DataWedge version info.
override
-
isDataWedgeAvailable(
) → Future< bool> -
Checks if DataWedge is available on the device.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerForNotification(
String notificationType) → Future< void> -
Registers for notifications of the specified type.
override
-
sendCommand(
{required String command, dynamic value, String? commandTag, bool requestResult = true}) → Future< void> -
Sends a command to DataWedge.
override
-
sendCommandBundle(
{required String command, required Map< String, dynamic> value, String? commandTag, bool requestResult = true}) → Future<void> -
Sends a command with a Map value to DataWedge.
override
-
sendIntent(
{required Map< String, dynamic> extras, String? action, String? targetPackage, String? commandTag, bool requestResult = true, bool orderedBroadcast = false, bool includeApplicationPackage = false}) → Future<void> -
Sends an intent to DataWedge or another package.
override
-
startSoftScan(
) → Future< void> -
Starts a software scan trigger.
override
-
switchToProfile(
String profileName) → Future< void> -
Switches to the specified profile.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterForNotification(
String notificationType) → Future< void> -
Unregisters from notifications of the specified type.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited